@@ -14,24 +14,28 @@ Usage::
     ```
 """
 import sys
-from typing import IO, Any, Dict, Mapping, Sequence, Type, Union, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
-from botocore.response import StreamingBody
 
 from .paginator import ListRuleGroupsNamespacesPaginator, ListWorkspacesPaginator
 from .type_defs import (
+    BlobTypeDef,
     CreateAlertManagerDefinitionResponseTypeDef,
+    CreateLoggingConfigurationResponseTypeDef,
     CreateRuleGroupsNamespaceResponseTypeDef,
     CreateWorkspaceResponseTypeDef,
     DescribeAlertManagerDefinitionResponseTypeDef,
+    DescribeLoggingConfigurationResponseTypeDef,
     DescribeRuleGroupsNamespaceResponseTypeDef,
     DescribeWorkspaceResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     ListRuleGroupsNamespacesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     ListWorkspacesResponseTypeDef,
     PutAlertManagerDefinitionResponseTypeDef,
     PutRuleGroupsNamespaceResponseTypeDef,
+    UpdateLoggingConfigurationResponseTypeDef,
 )
 from .waiter import WorkspaceActiveWaiter, WorkspaceDeletedWaiter
 
@@ -88,12 +92,16 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#close)
+        """
+
     def create_alert_manager_definition(
-        self,
-        *,
-        data: Union[str, bytes, IO[Any], StreamingBody],
-        workspaceId: str,
-        clientToken: str = ...
+        self, *, workspaceId: str, data: BlobTypeDef, clientToken: str = ...
     ) -> CreateAlertManagerDefinitionResponseTypeDef:
         """
         Create an alert manager definition.
@@ -102,12 +110,22 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#create_alert_manager_definition)
         """
 
+    def create_logging_configuration(
+        self, *, workspaceId: str, logGroupArn: str, clientToken: str = ...
+    ) -> CreateLoggingConfigurationResponseTypeDef:
+        """
+        Create logging configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Client.create_logging_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#create_logging_configuration)
+        """
+
     def create_rule_groups_namespace(
         self,
         *,
-        data: Union[str, bytes, IO[Any], StreamingBody],
-        name: str,
         workspaceId: str,
+        name: str,
+        data: BlobTypeDef,
         clientToken: str = ...,
         tags: Mapping[str, str] = ...
     ) -> CreateRuleGroupsNamespaceResponseTypeDef:
@@ -128,7 +146,9 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#create_workspace)
         """
 
-    def delete_alert_manager_definition(self, *, workspaceId: str, clientToken: str = ...) -> None:
+    def delete_alert_manager_definition(
+        self, *, workspaceId: str, clientToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes an alert manager definition.
 
@@ -136,9 +156,19 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#delete_alert_manager_definition)
         """
 
+    def delete_logging_configuration(
+        self, *, workspaceId: str, clientToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
+        """
+        Delete logging configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Client.delete_logging_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#delete_logging_configuration)
+        """
+
     def delete_rule_groups_namespace(
-        self, *, name: str, workspaceId: str, clientToken: str = ...
-    ) -> None:
+        self, *, workspaceId: str, name: str, clientToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Delete a rule groups namespace.
 
@@ -146,7 +176,9 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#delete_rule_groups_namespace)
         """
 
-    def delete_workspace(self, *, workspaceId: str, clientToken: str = ...) -> None:
+    def delete_workspace(
+        self, *, workspaceId: str, clientToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes an AMP workspace.
 
@@ -164,8 +196,18 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#describe_alert_manager_definition)
         """
 
+    def describe_logging_configuration(
+        self, *, workspaceId: str
+    ) -> DescribeLoggingConfigurationResponseTypeDef:
+        """
+        Describes logging configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Client.describe_logging_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#describe_logging_configuration)
+        """
+
     def describe_rule_groups_namespace(
-        self, *, name: str, workspaceId: str
+        self, *, workspaceId: str, name: str
     ) -> DescribeRuleGroupsNamespaceResponseTypeDef:
         """
         Describe a rule groups namespace.
@@ -197,7 +239,7 @@ class PrometheusServiceClient(BaseClient):
         """
 
     def list_rule_groups_namespaces(
-        self, *, workspaceId: str, maxResults: int = ..., name: str = ..., nextToken: str = ...
+        self, *, workspaceId: str, name: str = ..., nextToken: str = ..., maxResults: int = ...
     ) -> ListRuleGroupsNamespacesResponseTypeDef:
         """
         Lists rule groups namespaces.
@@ -215,7 +257,7 @@ class PrometheusServiceClient(BaseClient):
         """
 
     def list_workspaces(
-        self, *, alias: str = ..., maxResults: int = ..., nextToken: str = ...
+        self, *, nextToken: str = ..., alias: str = ..., maxResults: int = ...
     ) -> ListWorkspacesResponseTypeDef:
         """
         Lists all AMP workspaces, including workspaces being created or deleted.
@@ -225,11 +267,7 @@ class PrometheusServiceClient(BaseClient):
         """
 
     def put_alert_manager_definition(
-        self,
-        *,
-        data: Union[str, bytes, IO[Any], StreamingBody],
-        workspaceId: str,
-        clientToken: str = ...
+        self, *, workspaceId: str, data: BlobTypeDef, clientToken: str = ...
     ) -> PutAlertManagerDefinitionResponseTypeDef:
         """
         Update an alert manager definition.
@@ -239,12 +277,7 @@ class PrometheusServiceClient(BaseClient):
         """
 
     def put_rule_groups_namespace(
-        self,
-        *,
-        data: Union[str, bytes, IO[Any], StreamingBody],
-        name: str,
-        workspaceId: str,
-        clientToken: str = ...
+        self, *, workspaceId: str, name: str, data: BlobTypeDef, clientToken: str = ...
     ) -> PutRuleGroupsNamespaceResponseTypeDef:
         """
         Update a rule groups namespace.
@@ -269,9 +302,19 @@ class PrometheusServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#untag_resource)
         """
 
+    def update_logging_configuration(
+        self, *, workspaceId: str, logGroupArn: str, clientToken: str = ...
+    ) -> UpdateLoggingConfigurationResponseTypeDef:
+        """
+        Update logging configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Client.update_logging_configuration)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/client/#update_logging_configuration)
+        """
+
     def update_workspace_alias(
         self, *, workspaceId: str, alias: str = ..., clientToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates an AMP workspace alias.
 
