@@ -6,9 +6,9 @@ Type annotations for amp service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_amp.type_defs import AlertManagerDefinitionDescriptionTypeDef
+    from mypy_boto3_amp.type_defs import AlertManagerDefinitionStatusTypeDef
 
-    data: AlertManagerDefinitionDescriptionTypeDef = {...}
+    data: AlertManagerDefinitionStatusTypeDef = ...
     ```
 """
 import sys
@@ -19,6 +19,7 @@ from botocore.response import StreamingBody
 
 from .literals import (
     AlertManagerDefinitionStatusCodeType,
+    LoggingConfigurationStatusCodeType,
     RuleGroupsNamespaceStatusCodeType,
     WorkspaceStatusCodeType,
 )
@@ -30,59 +31,60 @@ else:
 
 
 __all__ = (
-    "AlertManagerDefinitionDescriptionTypeDef",
     "AlertManagerDefinitionStatusTypeDef",
-    "CreateAlertManagerDefinitionRequestRequestTypeDef",
-    "CreateAlertManagerDefinitionResponseTypeDef",
-    "CreateRuleGroupsNamespaceRequestRequestTypeDef",
-    "CreateRuleGroupsNamespaceResponseTypeDef",
+    "BlobTypeDef",
+    "ResponseMetadataTypeDef",
+    "CreateLoggingConfigurationRequestRequestTypeDef",
+    "LoggingConfigurationStatusTypeDef",
+    "RuleGroupsNamespaceStatusTypeDef",
     "CreateWorkspaceRequestRequestTypeDef",
-    "CreateWorkspaceResponseTypeDef",
+    "WorkspaceStatusTypeDef",
     "DeleteAlertManagerDefinitionRequestRequestTypeDef",
+    "DeleteLoggingConfigurationRequestRequestTypeDef",
     "DeleteRuleGroupsNamespaceRequestRequestTypeDef",
     "DeleteWorkspaceRequestRequestTypeDef",
     "DescribeAlertManagerDefinitionRequestRequestTypeDef",
-    "DescribeAlertManagerDefinitionResponseTypeDef",
+    "DescribeLoggingConfigurationRequestRequestTypeDef",
     "DescribeRuleGroupsNamespaceRequestRequestTypeDef",
-    "DescribeRuleGroupsNamespaceResponseTypeDef",
     "DescribeWorkspaceRequestRequestTypeDef",
-    "DescribeWorkspaceRequestWorkspaceActiveWaitTypeDef",
-    "DescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef",
-    "DescribeWorkspaceResponseTypeDef",
-    "ListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef",
-    "ListRuleGroupsNamespacesRequestRequestTypeDef",
-    "ListRuleGroupsNamespacesResponseTypeDef",
-    "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "ListWorkspacesRequestListWorkspacesPaginateTypeDef",
-    "ListWorkspacesRequestRequestTypeDef",
-    "ListWorkspacesResponseTypeDef",
+    "WaiterConfigTypeDef",
     "PaginatorConfigTypeDef",
-    "PutAlertManagerDefinitionRequestRequestTypeDef",
-    "PutAlertManagerDefinitionResponseTypeDef",
-    "PutRuleGroupsNamespaceRequestRequestTypeDef",
-    "PutRuleGroupsNamespaceResponseTypeDef",
-    "ResponseMetadataTypeDef",
-    "RuleGroupsNamespaceDescriptionTypeDef",
-    "RuleGroupsNamespaceStatusTypeDef",
-    "RuleGroupsNamespaceSummaryTypeDef",
+    "ListRuleGroupsNamespacesRequestRequestTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListWorkspacesRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "UpdateLoggingConfigurationRequestRequestTypeDef",
     "UpdateWorkspaceAliasRequestRequestTypeDef",
-    "WaiterConfigTypeDef",
-    "WorkspaceDescriptionTypeDef",
-    "WorkspaceStatusTypeDef",
-    "WorkspaceSummaryTypeDef",
-)
-
-AlertManagerDefinitionDescriptionTypeDef = TypedDict(
     "AlertManagerDefinitionDescriptionTypeDef",
-    {
-        "createdAt": datetime,
-        "data": bytes,
-        "modifiedAt": datetime,
-        "status": "AlertManagerDefinitionStatusTypeDef",
-    },
+    "CreateAlertManagerDefinitionRequestRequestTypeDef",
+    "CreateRuleGroupsNamespaceRequestRequestTypeDef",
+    "PutAlertManagerDefinitionRequestRequestTypeDef",
+    "PutRuleGroupsNamespaceRequestRequestTypeDef",
+    "CreateAlertManagerDefinitionResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "PutAlertManagerDefinitionResponseTypeDef",
+    "CreateLoggingConfigurationResponseTypeDef",
+    "LoggingConfigurationMetadataTypeDef",
+    "UpdateLoggingConfigurationResponseTypeDef",
+    "CreateRuleGroupsNamespaceResponseTypeDef",
+    "PutRuleGroupsNamespaceResponseTypeDef",
+    "RuleGroupsNamespaceDescriptionTypeDef",
+    "RuleGroupsNamespaceSummaryTypeDef",
+    "CreateWorkspaceResponseTypeDef",
+    "WorkspaceDescriptionTypeDef",
+    "WorkspaceSummaryTypeDef",
+    "DescribeWorkspaceRequestWorkspaceActiveWaitTypeDef",
+    "DescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef",
+    "ListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef",
+    "ListWorkspacesRequestListWorkspacesPaginateTypeDef",
+    "DescribeAlertManagerDefinitionResponseTypeDef",
+    "DescribeLoggingConfigurationResponseTypeDef",
+    "DescribeRuleGroupsNamespaceResponseTypeDef",
+    "ListRuleGroupsNamespacesResponseTypeDef",
+    "DescribeWorkspaceResponseTypeDef",
+    "ListWorkspacesResponseTypeDef",
 )
 
 _RequiredAlertManagerDefinitionStatusTypeDef = TypedDict(
@@ -106,15 +108,27 @@ class AlertManagerDefinitionStatusTypeDef(
     pass
 
 
-_RequiredCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAlertManagerDefinitionRequestRequestTypeDef",
+BlobTypeDef = Union[str, bytes, IO[Any], StreamingBody]
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "data": Union[str, bytes, IO[Any], StreamingBody],
-        "workspaceId": str,
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
-_OptionalCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAlertManagerDefinitionRequestRequestTypeDef",
+
+_RequiredCreateLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLoggingConfigurationRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+        "logGroupArn": str,
+    },
+)
+_OptionalCreateLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLoggingConfigurationRequestRequestTypeDef",
     {
         "clientToken": str,
     },
@@ -122,56 +136,54 @@ _OptionalCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
 )
 
 
-class CreateAlertManagerDefinitionRequestRequestTypeDef(
-    _RequiredCreateAlertManagerDefinitionRequestRequestTypeDef,
-    _OptionalCreateAlertManagerDefinitionRequestRequestTypeDef,
+class CreateLoggingConfigurationRequestRequestTypeDef(
+    _RequiredCreateLoggingConfigurationRequestRequestTypeDef,
+    _OptionalCreateLoggingConfigurationRequestRequestTypeDef,
 ):
     pass
 
 
-CreateAlertManagerDefinitionResponseTypeDef = TypedDict(
-    "CreateAlertManagerDefinitionResponseTypeDef",
+_RequiredLoggingConfigurationStatusTypeDef = TypedDict(
+    "_RequiredLoggingConfigurationStatusTypeDef",
     {
-        "status": "AlertManagerDefinitionStatusTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "statusCode": LoggingConfigurationStatusCodeType,
     },
 )
-
-_RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef",
+_OptionalLoggingConfigurationStatusTypeDef = TypedDict(
+    "_OptionalLoggingConfigurationStatusTypeDef",
     {
-        "data": Union[str, bytes, IO[Any], StreamingBody],
-        "name": str,
-        "workspaceId": str,
-    },
-)
-_OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef",
-    {
-        "clientToken": str,
-        "tags": Mapping[str, str],
+        "statusReason": str,
     },
     total=False,
 )
 
 
-class CreateRuleGroupsNamespaceRequestRequestTypeDef(
-    _RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef,
-    _OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef,
+class LoggingConfigurationStatusTypeDef(
+    _RequiredLoggingConfigurationStatusTypeDef, _OptionalLoggingConfigurationStatusTypeDef
 ):
     pass
 
 
-CreateRuleGroupsNamespaceResponseTypeDef = TypedDict(
-    "CreateRuleGroupsNamespaceResponseTypeDef",
+_RequiredRuleGroupsNamespaceStatusTypeDef = TypedDict(
+    "_RequiredRuleGroupsNamespaceStatusTypeDef",
     {
-        "arn": str,
-        "name": str,
-        "status": "RuleGroupsNamespaceStatusTypeDef",
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "statusCode": RuleGroupsNamespaceStatusCodeType,
     },
 )
+_OptionalRuleGroupsNamespaceStatusTypeDef = TypedDict(
+    "_OptionalRuleGroupsNamespaceStatusTypeDef",
+    {
+        "statusReason": str,
+    },
+    total=False,
+)
+
+
+class RuleGroupsNamespaceStatusTypeDef(
+    _RequiredRuleGroupsNamespaceStatusTypeDef, _OptionalRuleGroupsNamespaceStatusTypeDef
+):
+    pass
+
 
 CreateWorkspaceRequestRequestTypeDef = TypedDict(
     "CreateWorkspaceRequestRequestTypeDef",
@@ -183,14 +195,10 @@ CreateWorkspaceRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-CreateWorkspaceResponseTypeDef = TypedDict(
-    "CreateWorkspaceResponseTypeDef",
+WorkspaceStatusTypeDef = TypedDict(
+    "WorkspaceStatusTypeDef",
     {
-        "arn": str,
-        "status": "WorkspaceStatusTypeDef",
-        "tags": Dict[str, str],
-        "workspaceId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "statusCode": WorkspaceStatusCodeType,
     },
 )
 
@@ -216,11 +224,33 @@ class DeleteAlertManagerDefinitionRequestRequestTypeDef(
     pass
 
 
+_RequiredDeleteLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteLoggingConfigurationRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+    },
+)
+_OptionalDeleteLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteLoggingConfigurationRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteLoggingConfigurationRequestRequestTypeDef(
+    _RequiredDeleteLoggingConfigurationRequestRequestTypeDef,
+    _OptionalDeleteLoggingConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredDeleteRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
     "_RequiredDeleteRuleGroupsNamespaceRequestRequestTypeDef",
     {
-        "name": str,
         "workspaceId": str,
+        "name": str,
     },
 )
 _OptionalDeleteRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
@@ -267,27 +297,18 @@ DescribeAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeAlertManagerDefinitionResponseTypeDef = TypedDict(
-    "DescribeAlertManagerDefinitionResponseTypeDef",
+DescribeLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "DescribeLoggingConfigurationRequestRequestTypeDef",
     {
-        "alertManagerDefinition": "AlertManagerDefinitionDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "workspaceId": str,
     },
 )
 
 DescribeRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
     "DescribeRuleGroupsNamespaceRequestRequestTypeDef",
     {
-        "name": str,
         "workspaceId": str,
-    },
-)
-
-DescribeRuleGroupsNamespaceResponseTypeDef = TypedDict(
-    "DescribeRuleGroupsNamespaceResponseTypeDef",
-    {
-        "ruleGroupsNamespace": "RuleGroupsNamespaceDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "name": str,
     },
 )
 
@@ -298,157 +319,15 @@ DescribeWorkspaceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef = TypedDict(
-    "_RequiredDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef",
+WaiterConfigTypeDef = TypedDict(
+    "WaiterConfigTypeDef",
     {
-        "workspaceId": str,
-    },
-)
-_OptionalDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef = TypedDict(
-    "_OptionalDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef",
-    {
-        "WaiterConfig": "WaiterConfigTypeDef",
+        "Delay": int,
+        "MaxAttempts": int,
     },
     total=False,
 )
 
-
-class DescribeWorkspaceRequestWorkspaceActiveWaitTypeDef(
-    _RequiredDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef,
-    _OptionalDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef,
-):
-    pass
-
-
-_RequiredDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef = TypedDict(
-    "_RequiredDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef",
-    {
-        "workspaceId": str,
-    },
-)
-_OptionalDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef = TypedDict(
-    "_OptionalDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef",
-    {
-        "WaiterConfig": "WaiterConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef(
-    _RequiredDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef,
-    _OptionalDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef,
-):
-    pass
-
-
-DescribeWorkspaceResponseTypeDef = TypedDict(
-    "DescribeWorkspaceResponseTypeDef",
-    {
-        "workspace": "WorkspaceDescriptionTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef = TypedDict(
-    "_RequiredListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef",
-    {
-        "workspaceId": str,
-    },
-)
-_OptionalListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef = TypedDict(
-    "_OptionalListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef",
-    {
-        "name": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef(
-    _RequiredListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef,
-    _OptionalListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef,
-):
-    pass
-
-
-_RequiredListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
-    "_RequiredListRuleGroupsNamespacesRequestRequestTypeDef",
-    {
-        "workspaceId": str,
-    },
-)
-_OptionalListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
-    "_OptionalListRuleGroupsNamespacesRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "name": str,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class ListRuleGroupsNamespacesRequestRequestTypeDef(
-    _RequiredListRuleGroupsNamespacesRequestRequestTypeDef,
-    _OptionalListRuleGroupsNamespacesRequestRequestTypeDef,
-):
-    pass
-
-
-ListRuleGroupsNamespacesResponseTypeDef = TypedDict(
-    "ListRuleGroupsNamespacesResponseTypeDef",
-    {
-        "nextToken": str,
-        "ruleGroupsNamespaces": List["RuleGroupsNamespaceSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListTagsForResourceRequestRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestRequestTypeDef",
-    {
-        "resourceArn": str,
-    },
-)
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListWorkspacesRequestListWorkspacesPaginateTypeDef = TypedDict(
-    "ListWorkspacesRequestListWorkspacesPaginateTypeDef",
-    {
-        "alias": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-ListWorkspacesRequestRequestTypeDef = TypedDict(
-    "ListWorkspacesRequestRequestTypeDef",
-    {
-        "alias": str,
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-ListWorkspacesResponseTypeDef = TypedDict(
-    "ListWorkspacesResponseTypeDef",
-    {
-        "nextToken": str,
-        "workspaces": List["WorkspaceSummaryTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -459,155 +338,47 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_RequiredPutAlertManagerDefinitionRequestRequestTypeDef",
+_RequiredListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
+    "_RequiredListRuleGroupsNamespacesRequestRequestTypeDef",
     {
-        "data": Union[str, bytes, IO[Any], StreamingBody],
         "workspaceId": str,
     },
 )
-_OptionalPutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
-    "_OptionalPutAlertManagerDefinitionRequestRequestTypeDef",
+_OptionalListRuleGroupsNamespacesRequestRequestTypeDef = TypedDict(
+    "_OptionalListRuleGroupsNamespacesRequestRequestTypeDef",
     {
-        "clientToken": str,
-    },
-    total=False,
-)
-
-
-class PutAlertManagerDefinitionRequestRequestTypeDef(
-    _RequiredPutAlertManagerDefinitionRequestRequestTypeDef,
-    _OptionalPutAlertManagerDefinitionRequestRequestTypeDef,
-):
-    pass
-
-
-PutAlertManagerDefinitionResponseTypeDef = TypedDict(
-    "PutAlertManagerDefinitionResponseTypeDef",
-    {
-        "status": "AlertManagerDefinitionStatusTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredPutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_RequiredPutRuleGroupsNamespaceRequestRequestTypeDef",
-    {
-        "data": Union[str, bytes, IO[Any], StreamingBody],
         "name": str,
-        "workspaceId": str,
-    },
-)
-_OptionalPutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
-    "_OptionalPutRuleGroupsNamespaceRequestRequestTypeDef",
-    {
-        "clientToken": str,
+        "nextToken": str,
+        "maxResults": int,
     },
     total=False,
 )
 
 
-class PutRuleGroupsNamespaceRequestRequestTypeDef(
-    _RequiredPutRuleGroupsNamespaceRequestRequestTypeDef,
-    _OptionalPutRuleGroupsNamespaceRequestRequestTypeDef,
+class ListRuleGroupsNamespacesRequestRequestTypeDef(
+    _RequiredListRuleGroupsNamespacesRequestRequestTypeDef,
+    _OptionalListRuleGroupsNamespacesRequestRequestTypeDef,
 ):
     pass
 
 
-PutRuleGroupsNamespaceResponseTypeDef = TypedDict(
-    "PutRuleGroupsNamespaceResponseTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
-        "arn": str,
-        "name": str,
-        "status": "RuleGroupsNamespaceStatusTypeDef",
-        "tags": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "resourceArn": str,
     },
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+ListWorkspacesRequestRequestTypeDef = TypedDict(
+    "ListWorkspacesRequestRequestTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-_RequiredRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
-    "_RequiredRuleGroupsNamespaceDescriptionTypeDef",
-    {
-        "arn": str,
-        "createdAt": datetime,
-        "data": bytes,
-        "modifiedAt": datetime,
-        "name": str,
-        "status": "RuleGroupsNamespaceStatusTypeDef",
-    },
-)
-_OptionalRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
-    "_OptionalRuleGroupsNamespaceDescriptionTypeDef",
-    {
-        "tags": Dict[str, str],
+        "nextToken": str,
+        "alias": str,
+        "maxResults": int,
     },
     total=False,
 )
 
-
-class RuleGroupsNamespaceDescriptionTypeDef(
-    _RequiredRuleGroupsNamespaceDescriptionTypeDef, _OptionalRuleGroupsNamespaceDescriptionTypeDef
-):
-    pass
-
-
-_RequiredRuleGroupsNamespaceStatusTypeDef = TypedDict(
-    "_RequiredRuleGroupsNamespaceStatusTypeDef",
-    {
-        "statusCode": RuleGroupsNamespaceStatusCodeType,
-    },
-)
-_OptionalRuleGroupsNamespaceStatusTypeDef = TypedDict(
-    "_OptionalRuleGroupsNamespaceStatusTypeDef",
-    {
-        "statusReason": str,
-    },
-    total=False,
-)
-
-
-class RuleGroupsNamespaceStatusTypeDef(
-    _RequiredRuleGroupsNamespaceStatusTypeDef, _OptionalRuleGroupsNamespaceStatusTypeDef
-):
-    pass
-
-
-_RequiredRuleGroupsNamespaceSummaryTypeDef = TypedDict(
-    "_RequiredRuleGroupsNamespaceSummaryTypeDef",
-    {
-        "arn": str,
-        "createdAt": datetime,
-        "modifiedAt": datetime,
-        "name": str,
-        "status": "RuleGroupsNamespaceStatusTypeDef",
-    },
-)
-_OptionalRuleGroupsNamespaceSummaryTypeDef = TypedDict(
-    "_OptionalRuleGroupsNamespaceSummaryTypeDef",
-    {
-        "tags": Dict[str, str],
-    },
-    total=False,
-)
-
-
-class RuleGroupsNamespaceSummaryTypeDef(
-    _RequiredRuleGroupsNamespaceSummaryTypeDef, _OptionalRuleGroupsNamespaceSummaryTypeDef
-):
-    pass
-
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -624,6 +395,29 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateLoggingConfigurationRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+        "logGroupArn": str,
+    },
+)
+_OptionalUpdateLoggingConfigurationRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateLoggingConfigurationRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateLoggingConfigurationRequestRequestTypeDef(
+    _RequiredUpdateLoggingConfigurationRequestRequestTypeDef,
+    _OptionalUpdateLoggingConfigurationRequestRequestTypeDef,
+):
+    pass
+
+
 _RequiredUpdateWorkspaceAliasRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateWorkspaceAliasRequestRequestTypeDef",
     {
@@ -647,22 +441,260 @@ class UpdateWorkspaceAliasRequestRequestTypeDef(
     pass
 
 
-WaiterConfigTypeDef = TypedDict(
-    "WaiterConfigTypeDef",
+AlertManagerDefinitionDescriptionTypeDef = TypedDict(
+    "AlertManagerDefinitionDescriptionTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "status": AlertManagerDefinitionStatusTypeDef,
+        "data": bytes,
+        "createdAt": datetime,
+        "modifiedAt": datetime,
+    },
+)
+
+_RequiredCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAlertManagerDefinitionRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+        "data": BlobTypeDef,
+    },
+)
+_OptionalCreateAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAlertManagerDefinitionRequestRequestTypeDef",
+    {
+        "clientToken": str,
     },
     total=False,
 )
 
+
+class CreateAlertManagerDefinitionRequestRequestTypeDef(
+    _RequiredCreateAlertManagerDefinitionRequestRequestTypeDef,
+    _OptionalCreateAlertManagerDefinitionRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+        "name": str,
+        "data": BlobTypeDef,
+    },
+)
+_OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef",
+    {
+        "clientToken": str,
+        "tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateRuleGroupsNamespaceRequestRequestTypeDef(
+    _RequiredCreateRuleGroupsNamespaceRequestRequestTypeDef,
+    _OptionalCreateRuleGroupsNamespaceRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredPutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "_RequiredPutAlertManagerDefinitionRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+        "data": BlobTypeDef,
+    },
+)
+_OptionalPutAlertManagerDefinitionRequestRequestTypeDef = TypedDict(
+    "_OptionalPutAlertManagerDefinitionRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class PutAlertManagerDefinitionRequestRequestTypeDef(
+    _RequiredPutAlertManagerDefinitionRequestRequestTypeDef,
+    _OptionalPutAlertManagerDefinitionRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredPutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "_RequiredPutRuleGroupsNamespaceRequestRequestTypeDef",
+    {
+        "workspaceId": str,
+        "name": str,
+        "data": BlobTypeDef,
+    },
+)
+_OptionalPutRuleGroupsNamespaceRequestRequestTypeDef = TypedDict(
+    "_OptionalPutRuleGroupsNamespaceRequestRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class PutRuleGroupsNamespaceRequestRequestTypeDef(
+    _RequiredPutRuleGroupsNamespaceRequestRequestTypeDef,
+    _OptionalPutRuleGroupsNamespaceRequestRequestTypeDef,
+):
+    pass
+
+
+CreateAlertManagerDefinitionResponseTypeDef = TypedDict(
+    "CreateAlertManagerDefinitionResponseTypeDef",
+    {
+        "status": AlertManagerDefinitionStatusTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutAlertManagerDefinitionResponseTypeDef = TypedDict(
+    "PutAlertManagerDefinitionResponseTypeDef",
+    {
+        "status": AlertManagerDefinitionStatusTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateLoggingConfigurationResponseTypeDef = TypedDict(
+    "CreateLoggingConfigurationResponseTypeDef",
+    {
+        "status": LoggingConfigurationStatusTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+LoggingConfigurationMetadataTypeDef = TypedDict(
+    "LoggingConfigurationMetadataTypeDef",
+    {
+        "status": LoggingConfigurationStatusTypeDef,
+        "workspace": str,
+        "logGroupArn": str,
+        "createdAt": datetime,
+        "modifiedAt": datetime,
+    },
+)
+
+UpdateLoggingConfigurationResponseTypeDef = TypedDict(
+    "UpdateLoggingConfigurationResponseTypeDef",
+    {
+        "status": LoggingConfigurationStatusTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateRuleGroupsNamespaceResponseTypeDef = TypedDict(
+    "CreateRuleGroupsNamespaceResponseTypeDef",
+    {
+        "name": str,
+        "arn": str,
+        "status": RuleGroupsNamespaceStatusTypeDef,
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutRuleGroupsNamespaceResponseTypeDef = TypedDict(
+    "PutRuleGroupsNamespaceResponseTypeDef",
+    {
+        "name": str,
+        "arn": str,
+        "status": RuleGroupsNamespaceStatusTypeDef,
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
+    "_RequiredRuleGroupsNamespaceDescriptionTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "status": RuleGroupsNamespaceStatusTypeDef,
+        "data": bytes,
+        "createdAt": datetime,
+        "modifiedAt": datetime,
+    },
+)
+_OptionalRuleGroupsNamespaceDescriptionTypeDef = TypedDict(
+    "_OptionalRuleGroupsNamespaceDescriptionTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class RuleGroupsNamespaceDescriptionTypeDef(
+    _RequiredRuleGroupsNamespaceDescriptionTypeDef, _OptionalRuleGroupsNamespaceDescriptionTypeDef
+):
+    pass
+
+
+_RequiredRuleGroupsNamespaceSummaryTypeDef = TypedDict(
+    "_RequiredRuleGroupsNamespaceSummaryTypeDef",
+    {
+        "arn": str,
+        "name": str,
+        "status": RuleGroupsNamespaceStatusTypeDef,
+        "createdAt": datetime,
+        "modifiedAt": datetime,
+    },
+)
+_OptionalRuleGroupsNamespaceSummaryTypeDef = TypedDict(
+    "_OptionalRuleGroupsNamespaceSummaryTypeDef",
+    {
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class RuleGroupsNamespaceSummaryTypeDef(
+    _RequiredRuleGroupsNamespaceSummaryTypeDef, _OptionalRuleGroupsNamespaceSummaryTypeDef
+):
+    pass
+
+
+CreateWorkspaceResponseTypeDef = TypedDict(
+    "CreateWorkspaceResponseTypeDef",
+    {
+        "workspaceId": str,
+        "arn": str,
+        "status": WorkspaceStatusTypeDef,
+        "tags": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 _RequiredWorkspaceDescriptionTypeDef = TypedDict(
     "_RequiredWorkspaceDescriptionTypeDef",
     {
-        "arn": str,
-        "createdAt": datetime,
-        "status": "WorkspaceStatusTypeDef",
         "workspaceId": str,
+        "arn": str,
+        "status": WorkspaceStatusTypeDef,
+        "createdAt": datetime,
     },
 )
 _OptionalWorkspaceDescriptionTypeDef = TypedDict(
@@ -682,20 +714,13 @@ class WorkspaceDescriptionTypeDef(
     pass
 
 
-WorkspaceStatusTypeDef = TypedDict(
-    "WorkspaceStatusTypeDef",
-    {
-        "statusCode": WorkspaceStatusCodeType,
-    },
-)
-
 _RequiredWorkspaceSummaryTypeDef = TypedDict(
     "_RequiredWorkspaceSummaryTypeDef",
     {
-        "arn": str,
-        "createdAt": datetime,
-        "status": "WorkspaceStatusTypeDef",
         "workspaceId": str,
+        "arn": str,
+        "status": WorkspaceStatusTypeDef,
+        "createdAt": datetime,
     },
 )
 _OptionalWorkspaceSummaryTypeDef = TypedDict(
@@ -710,3 +735,130 @@ _OptionalWorkspaceSummaryTypeDef = TypedDict(
 
 class WorkspaceSummaryTypeDef(_RequiredWorkspaceSummaryTypeDef, _OptionalWorkspaceSummaryTypeDef):
     pass
+
+
+_RequiredDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef = TypedDict(
+    "_RequiredDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef",
+    {
+        "workspaceId": str,
+    },
+)
+_OptionalDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef = TypedDict(
+    "_OptionalDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeWorkspaceRequestWorkspaceActiveWaitTypeDef(
+    _RequiredDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef,
+    _OptionalDescribeWorkspaceRequestWorkspaceActiveWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef = TypedDict(
+    "_RequiredDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef",
+    {
+        "workspaceId": str,
+    },
+)
+_OptionalDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef = TypedDict(
+    "_OptionalDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef",
+    {
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef(
+    _RequiredDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef,
+    _OptionalDescribeWorkspaceRequestWorkspaceDeletedWaitTypeDef,
+):
+    pass
+
+
+_RequiredListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef = TypedDict(
+    "_RequiredListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef",
+    {
+        "workspaceId": str,
+    },
+)
+_OptionalListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef = TypedDict(
+    "_OptionalListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef",
+    {
+        "name": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef(
+    _RequiredListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef,
+    _OptionalListRuleGroupsNamespacesRequestListRuleGroupsNamespacesPaginateTypeDef,
+):
+    pass
+
+
+ListWorkspacesRequestListWorkspacesPaginateTypeDef = TypedDict(
+    "ListWorkspacesRequestListWorkspacesPaginateTypeDef",
+    {
+        "alias": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeAlertManagerDefinitionResponseTypeDef = TypedDict(
+    "DescribeAlertManagerDefinitionResponseTypeDef",
+    {
+        "alertManagerDefinition": AlertManagerDefinitionDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeLoggingConfigurationResponseTypeDef = TypedDict(
+    "DescribeLoggingConfigurationResponseTypeDef",
+    {
+        "loggingConfiguration": LoggingConfigurationMetadataTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeRuleGroupsNamespaceResponseTypeDef = TypedDict(
+    "DescribeRuleGroupsNamespaceResponseTypeDef",
+    {
+        "ruleGroupsNamespace": RuleGroupsNamespaceDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListRuleGroupsNamespacesResponseTypeDef = TypedDict(
+    "ListRuleGroupsNamespacesResponseTypeDef",
+    {
+        "ruleGroupsNamespaces": List[RuleGroupsNamespaceSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeWorkspaceResponseTypeDef = TypedDict(
+    "DescribeWorkspaceResponseTypeDef",
+    {
+        "workspace": WorkspaceDescriptionTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListWorkspacesResponseTypeDef = TypedDict(
+    "ListWorkspacesResponseTypeDef",
+    {
+        "workspaces": List[WorkspaceSummaryTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
