@@ -21,33 +21,33 @@ Usage::
     workspace_deleted_waiter: WorkspaceDeletedWaiter = client.get_waiter("workspace_deleted")
     ```
 """
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import WaiterConfigTypeDef
 
 __all__ = ("WorkspaceActiveWaiter", "WorkspaceDeletedWaiter")
 
 
-class WorkspaceActiveWaiter(Boto3Waiter):
+class WorkspaceActiveWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceActive)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspaceactivewaiter)
     """
 
-    def wait(self, *, workspaceId: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, workspaceId: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceActive.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspaceactivewaiter)
         """
 
 
-class WorkspaceDeletedWaiter(Boto3Waiter):
+class WorkspaceDeletedWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceDeleted)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspacedeletedwaiter)
     """
 
-    def wait(self, *, workspaceId: str, WaiterConfig: "WaiterConfigTypeDef" = ...) -> None:
+    def wait(self, *, workspaceId: str, WaiterConfig: WaiterConfigTypeDef = ...) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/amp.html#PrometheusService.Waiter.WorkspaceDeleted.wait)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_amp/waiters/#workspacedeletedwaiter)
